@@ -13,9 +13,9 @@ import (
 
 //go:generate go run scripts/include.go
 func main() {
-	//f, _ := os.Create("scc.pprof")
-	//pprof.StartCPUProfile(f)
-	//defer pprof.StopCPUProfile()
+	// f, _ := os.Create("scc.pprof")
+	// pprof.StartCPUProfile(f)
+	// defer pprof.StopCPUProfile()
 
 	if len(os.Args) == 2 && strings.HasPrefix(os.Args[1], "@") {
 		// handle "scc @flags.txt" syntax
@@ -159,7 +159,7 @@ func main() {
 		&processor.ExcludeFilename,
 		"exclude-file",
 		"n",
-		[]string{"package-lock.json", "Cargo.lock", "yarn.lock", "pubspec.lock", "Podfile.lock"},
+		[]string{"package-lock.json", "Cargo.lock", "yarn.lock", "pubspec.lock", "Podfile.lock", "pnpm-lock.yaml"},
 		"ignore files with matching names",
 	)
 	flags.BoolVarP(
@@ -211,6 +211,12 @@ func main() {
 		false,
 		"remove size calculation output",
 	)
+	flags.BoolVar(
+		&processor.HBorder,
+		"no-hborder",
+		false,
+		"remove horizontal borders between sections",
+	)
 	flags.StringVar(
 		&processor.SizeUnit,
 		"size-unit",
