@@ -3,6 +3,8 @@
 package processor
 
 import (
+	"bytes"
+	"compress/gzip"
 	"encoding/base64"
 	"fmt"
 	"os"
@@ -21,7 +23,7 @@ import (
 )
 
 // Version indicates the version of the application
-var Version = "3.3.4"
+var Version = "3.3.5"
 
 // Flags set via the CLI which control how the output is displayed
 
@@ -85,6 +87,9 @@ var CocomoProjectType = "organic"
 // Size toggles the Size calculation
 var Size = false
 
+// Draw horizontal borders between sections.
+var HBorder = false
+
 // SizeUnit determines what size calculation is used for megabytes
 var SizeUnit = "si"
 
@@ -266,11 +271,11 @@ func ProcessConstants() {
 	// Configure COCOMO setting
 	_, ok := projectType[strings.ToLower(CocomoProjectType)]
 	if !ok {
-		// lets see if we can turn it into a custom one
+		// let's see if we can turn it into a custom one
 		spl := strings.Split(CocomoProjectType, ",")
 		val := []float64{}
 		if len(spl) == 5 {
-			// lets try to convert to float if we can
+			// let's try to convert to float if we can
 			for i := 1; i < 5; i++ {
 				f, err := strconv.ParseFloat(spl[i], 64)
 				if err == nil {
@@ -330,7 +335,7 @@ func setupCountAs() {
 			// See if we can identify based on language name which is the most
 			// reliable as the name should be unique
 			for name := range languageDatabase {
-				if strings.ToLower(name) == strings.ToLower(t[1]) {
+				if strings.EqualFold(name, t[1]) {
 					ExtensionToLanguage[strings.ToLower(t[0])] = []string{name}
 					identified = true
 					if Debug {
@@ -504,13 +509,17 @@ func loadDatabase() map[string]Language {
 	var database map[string]Language
 	startTime := makeTimestampMilli()
 
-	data, err := base64.StdEncoding.DecodeString(languages)
+	gzData, err := base64.StdEncoding.DecodeString(languages)
 	if err != nil {
 		panic(fmt.Sprintf("failed to base64 decode languages: %v", err))
 	}
+	dataReader, err := gzip.NewReader(bytes.NewReader(gzData))
+	if err != nil {
+		panic(fmt.Sprintf("failed to create gzip reader: %v", err))
+	}
 
 	var json = jsoniter.ConfigCompatibleWithStandardLibrary
-	if err := json.Unmarshal(data, &database); err != nil {
+	if err := json.NewDecoder(dataReader).Decode(&database); err != nil {
 		panic(fmt.Sprintf("languages json invalid: %v", err))
 	}
 
@@ -534,7 +543,7 @@ func printLanguages() {
 	})
 
 	for _, name := range names {
-		fmt.Println(fmt.Sprintf("%s (%s)", name, strings.Join(append(database[name].Extensions, database[name].FileNames...), ",")))
+		fmt.Printf("%s (%s)\n", name, strings.Join(append(database[name].Extensions, database[name].FileNames...), ","))
 	}
 }
 
@@ -650,7 +659,7 @@ func Process() {
 
 	result := fileSummarize(fileSummaryJobQueue)
 	if FileOutput == "" {
-		fmt.Println(result)
+		fmt.Print(result)
 	} else {
 		_ = os.WriteFile(FileOutput, []byte(result), 0644)
 		fmt.Println("results written to " + FileOutput)
