@@ -117,8 +117,8 @@ func resetState(currentState int64) int64 {
 	return currentState
 }
 
-func stringState(fileJob *FileJob, index int, endPoint int, stringTrie *Trie, endString []byte, currentState int64, ignoreEscape bool) (int, int64) {
-	// Its not possible to enter this state without checking at least 1 byte so it is safe to check -1 here
+func stringState(fileJob *FileJob, index int, endPoint int, endString []byte, currentState int64, ignoreEscape bool) (int, int64) {
+	// It's not possible to enter this state without checking at least 1 byte so it is safe to check -1 here
 	// without checking if it is out of bounds first
 	for i := index; i < endPoint; i++ {
 		index = i
@@ -134,12 +134,11 @@ func stringState(fileJob *FileJob, index int, endPoint int, stringTrie *Trie, en
 		// if there is an escape symbol before us, investigate
 		if fileJob.Content[i-1] == '\\' {
 			num_escapes := 0
-			for j := i - 1; j > 0; j -= 1 {
-				if fileJob.Content[j] == '\\' {
-					num_escapes += 1
-				} else {
+			for j := i - 1; j > 0; j-- {
+				if fileJob.Content[j] != '\\' {
 					break
 				}
+				num_escapes++
 			}
 
 			// if number of escapes is even, all escapes are themselves escaped
@@ -163,7 +162,7 @@ func stringState(fileJob *FileJob, index int, endPoint int, stringTrie *Trie, en
 // This is a special state check pretty much only ever used by Python codebases
 // but potentially it could be expanded to deal with other types
 func docStringState(fileJob *FileJob, index int, endPoint int, stringTrie *Trie, endString []byte, currentState int64) (int, int64) {
-	// Its not possible to enter this state without checking at least 1 byte so it is safe to check -1 here
+	// It's not possible to enter this state without checking at least 1 byte so it is safe to check -1 here
 	// without checking if it is out of bounds first
 	for i := index; i < endPoint; i++ {
 		index = i
@@ -232,7 +231,7 @@ func codeState(
 
 		if shouldProcess(curByte, langFeatures.ProcessMask) {
 			if Duplicates {
-				// Technically this is wrong because we skip bytes so this is not a true
+				// Technically this is wrong because we skip bytes, so this is not a true
 				// hash of the file contents, but for duplicate files it shouldn't matter
 				// as both will skip the same way
 				digestible := []byte{fileJob.Content[index]}
@@ -324,7 +323,6 @@ func commentState(fileJob *FileJob, index int, endPoint int, currentState int64,
 func blankState(
 	fileJob *FileJob,
 	index int,
-	endPoint int,
 	currentState int64,
 	endComments [][]byte,
 	endString []byte,
@@ -465,7 +463,7 @@ func CountStats(fileJob *FileJob) {
 					&fileJob.Hash,
 				)
 			case SString:
-				index, currentState = stringState(fileJob, index, endPoint, langFeatures.Strings, endString, currentState, ignoreEscape)
+				index, currentState = stringState(fileJob, index, endPoint, endString, currentState, ignoreEscape)
 			case SDocString:
 				// For a docstring we can either move into blank in which case we count it as a docstring
 				// or back into code in which case it should be counted as code
@@ -486,7 +484,6 @@ func CountStats(fileJob *FileJob) {
 				index, currentState, endString, endComments, ignoreEscape = blankState(
 					fileJob,
 					index,
-					endPoint,
 					currentState,
 					endComments,
 					endString,
@@ -736,8 +733,8 @@ func processFile(job *FileJob) bool {
 			remapped = unknownRemapLanguage(job)
 		}
 
-		// if we didn't remap we then want to see if its a #! map
-		if remapped == false {
+		// if we didn't remap we then want to see if it's a #! map
+		if !remapped {
 			cutoff := 200
 
 			// To avoid runtime panic check if the content we are cutting is smaller than 200
